==> theme-bootstrap-2.0.7.tgz: package/src/helpers/cross-products.test.js <==
import { getWalletUrl, getBettingUrl, getProductUrl, getBlogUrl, WALLET_URLS, BLOG_URLS, BET_URLS, SCORUM_MULTI_DOMAIN } from './cross-products';
import { DEVELOPMENT, STAGING, PRODUCTION, RELEASE, LOCALES_DOMAIN_MAPPING, DEFAULT_LOCALE } from '../constants';

const locale = 'en-us';
const urlLocale = `/${locale}/`;

describe('Cross product utils', () => {
  describe('#getWalletUrl', () => {
    test('should get link for development', () => {
      process.env.PROJECT_ENV = DEVELOPMENT;
      expect(getWalletUrl(urlLocale)).toEqual(`//${WALLET_URLS[DEVELOPMENT]}${urlLocale}`);
    });

    test('should get link for staging', () => {
      process.env.PROJECT_ENV = STAGING;
      expect(getWalletUrl(urlLocale)).toEqual(`//${WALLET_URLS[STAGING]}${urlLocale}`);
    });

    test('should get link for release', () => {
      process.env.PROJECT_ENV = RELEASE;
      expect(getWalletUrl(urlLocale)).toEqual(`//${WALLET_URLS[RELEASE]}${urlLocale}`);
    });

    test('should get link for production', () => {
      process.env.PROJECT_ENV = PRODUCTION;
      expect(getWalletUrl(urlLocale)).toEqual(`//${WALLET_URLS[PRODUCTION]}${urlLocale}`);
    });

    test('should get development link by default', () => {
      process.env.PROJECT_ENV = null;
      expect(getWalletUrl(urlLocale)).toEqual(`//${WALLET_URLS[DEVELOPMENT]}${urlLocale}`);
    });
  });

  describe('#getBlogUrl', () => {
    test('should get link with env', () => {
      process.env.PROJECT_ENV = STAGING;
      const expectedValue = `//${BLOG_URLS[STAGING]}.${LOCALES_DOMAIN_MAPPING[DEFAULT_LOCALE]}${urlLocale}`;

      expect(getBlogUrl(urlLocale, locale)).toEqual(expectedValue);
    });

    test('should get link with default locale', () => {
      process.env.PROJECT_ENV = DEVELOPMENT;
      const expectedValue = `//${BLOG_URLS[DEVELOPMENT]}.${LOCALES_DOMAIN_MAPPING[locale]}/${DEFAULT_LOCALE}/`;

      expect(getBlogUrl(urlLocale)).toEqual(expectedValue);
    });

    test('should get link with default value', () => {
      process.env.PROJECT_ENV = null;
      const expectedValue = `//${BLOG_URLS[DEVELOPMENT]}.${LOCALES_DOMAIN_MAPPING[locale]}${urlLocale}`;

      expect(getBlogUrl(urlLocale, locale)).toEqual(expectedValue);
    });
  });

  describe('#getBettingUrl', () => {
    test('should get link with env', () => {
      process.env.PROJECT_ENV = STAGING;
      const expectedValue = `//${BET_URLS[STAGING]}${urlLocale}`;

      expect(getBettingUrl(urlLocale, locale)).toEqual(expectedValue);
    });

    test('should get link with default value', () => {
      process.env.PROJECT_ENV = null;
      const expectedValue = `//${BET_URLS[DEVELOPMENT]}${urlLocale}`;

      expect(getBettingUrl(urlLocale, locale)).toEqual(expectedValue);
    });
  });

  describe('#getProductUrl', () => {
    beforeEach(() => {
      process.env.PROJECT_ENV = PRODUCTION;
    });

    test('should get link for blog', () => {
      expect(getProductUrl('blog', locale)).toEqual(`//scorum.com${urlLocale}`);
    });

    test('should get link for wallet', () => {
      expect(getProductUrl('wallet', locale)).toEqual(`//${WALLET_URLS[PRODUCTION]}${urlLocale}`);
    });

    test('should get link for betting', () => {
      expect(getProductUrl('betting', locale)).toEqual(`//${BET_URLS[PRODUCTION]}${urlLocale}`);
    });

    test('should get link for other services', () => {
      expect(getProductUrl('explorer')).toEqual(`//explorer.${SCORUM_MULTI_DOMAIN}`);
    });
  });
});

==> theme-bootstrap-2.0.16.tgz: package/src/helpers/cross-products.test.js <==
import { getWalletUrl, getBettingUrl, getProductUrl, getBlogUrl, WALLET_URLS, BLOG_URLS, BET_URLS, SCORUM_MULTI_DOMAIN } from './cross-products';
import { DEVELOPMENT, STAGING, PRODUCTION, RELEASE, LOCALES_DOMAIN_MAPPING, DEFAULT_LOCALE } from '../constants';

const locale = 'en-us';
const urlLocale = `/${locale}/`;

describe('Cross product utils', () => {
  describe('#getWalletUrl', () => {
    test('should get link for development', () => {
      process.env.PROJECT_ENV = DEVELOPMENT;
      expect(getWalletUrl()).toEqual(`//${WALLET_URLS[DEVELOPMENT]}`);
    });

    test('should get link for staging', () => {
      process.env.PROJECT_ENV = STAGING;
      expect(getWalletUrl()).toEqual(`//${WALLET_URLS[STAGING]}`);
    });

    test('should get link for release', () => {
      process.env.PROJECT_ENV = RELEASE;
      expect(getWalletUrl()).toEqual(`//${WALLET_URLS[RELEASE]}`);
    });

    test('should get link for production', () => {
      process.env.PROJECT_ENV = PRODUCTION;
      expect(getWalletUrl()).toEqual(`//${WALLET_URLS[PRODUCTION]}`);
    });

    test('should get development link by default', () => {
      process.env.PROJECT_ENV = null;
      expect(getWalletUrl()).toEqual(`//${WALLET_URLS[DEVELOPMENT]}`);
    });
  });

  describe('#getBlogUrl', () => {
    test('should get link with env', () => {
      process.env.PROJECT_ENV = STAGING;
      const expectedValue = `//${BLOG_URLS[STAGING]}.${LOCALES_DOMAIN_MAPPING[DEFAULT_LOCALE]}`;

      expect(getBlogUrl(locale)).toEqual(expectedValue);
    });

    test('should get link with default locale', () => {
      process.env.PROJECT_ENV = DEVELOPMENT;
      const expectedValue = `//${BLOG_URLS[DEVELOPMENT]}.${LOCALES_DOMAIN_MAPPING[locale]}`;

      expect(getBlogUrl()).toEqual(expectedValue);
    });

    test('should get link with default value', () => {
      process.env.PROJECT_ENV = null;
      const expectedValue = `//${BLOG_URLS[DEVELOPMENT]}.${LOCALES_DOMAIN_MAPPING[locale]}`;

      expect(getBlogUrl(locale)).toEqual(expectedValue);
    });
  });

  describe('#getBettingUrl', () => {
    test('should get link with env', () => {
      process.env.PROJECT_ENV = STAGING;
      const expectedValue = `//${BET_URLS[STAGING]}`;

      expect(getBettingUrl(locale)).toEqual(expectedValue);
    });

    test('should get link with default value', () => {
      process.env.PROJECT_ENV = null;
      const expectedValue = `//${BET_URLS[DEVELOPMENT]}`;

      expect(getBettingUrl(locale)).toEqual(expectedValue);
    });
  });

  describe('#getProductUrl', () => {
    beforeEach(() => {
      process.env.PROJECT_ENV = PRODUCTION;
    });

    test('should get link for blog', () => {
      expect(getProductUrl('blog', locale)).toEqual(`//scorum.com${urlLocale}`);
    });

    test('should get link for wallet', () => {
      expect(getProductUrl('wallet', locale)).toEqual(`//${WALLET_URLS[PRODUCTION]}${urlLocale}`);
    });

    test('should get link for betting', () => {
      expect(getProductUrl('betting', locale)).toEqual(`//${BET_URLS[PRODUCTION]}${urlLocale}`);
    });

    test('should get link for other services', () => {
      expect(getProductUrl('explorer')).toEqual(`//explorer.${SCORUM_MULTI_DOMAIN}`);
    });
  });
});
